import sys
import importlib
from prometheus_client import CollectorRegistry, generate_latest

def main():
    module = sys.argv[1]
    module_name = "custom_exporters.%s" % module

    try:
        imported_module = importlib.import_module(module_name)
    except Exception:
        print("failed to load module %s" % module_name)
        sys.exit(1)

    registry = CollectorRegistry()
    try:
        cls = imported_module.CustomExporter(registry=registry)
    except Exception:
        print("failed to load CustomExporter class from module %s" % module_name)
        sys.exit(1)

    try:
        cls.generate()
    except Exception as e:
        print("generate failed: %s" % e)
        sys.exit(1)
    data = generate_latest(registry)
    print(data.decode('utf-8'))
